@@ -914,7 +914,9 @@ ags_sndfile_open(AgsSoundResource *sound_resource,
 	   SF_FORMAT_DOUBLE) & sndfile->info->format)){
   case SF_FORMAT_PCM_S8:
   {
-    format = AGS_SOUNDCARD_SIGNED_8_BIT;
+    //TODO:JK: implement me
+    //format = AGS_SOUNDCARD_SIGNED_8_BIT;
+    format = AGS_SOUNDCARD_DOUBLE;
   }
   break;
   case SF_FORMAT_PCM_16:
@@ -924,12 +926,16 @@ ags_sndfile_open(AgsSoundResource *sound_resource,
   break;
   case SF_FORMAT_PCM_24:
   {
-    format = AGS_SOUNDCARD_SIGNED_24_BIT;
+    //TODO:JK: implement me
+    //format = AGS_SOUNDCARD_SIGNED_24_BIT;
+    format = AGS_SOUNDCARD_DOUBLE;
   }
   break;
   case SF_FORMAT_PCM_32:
   {
-    format = AGS_SOUNDCARD_SIGNED_32_BIT;
+    //TODO:JK: implement me
+    //format = AGS_SOUNDCARD_SIGNED_32_BIT;
+    format = AGS_SOUNDCARD_DOUBLE;
   }
   break;
   case SF_FORMAT_FLOAT:
@@ -1104,7 +1110,11 @@ ags_sndfile_info(AgsSoundResource *sound_resource,
   pthread_mutex_lock(sndfile_mutex);
 
   if(frame_count != NULL){
-    *frame_count = sndfile->info->frames;
+    if(sndfile->info != NULL){
+      *frame_count = sndfile->info->frames;
+    }else{
+      *frame_count = 0;
+    }
   }
 
   pthread_mutex_unlock(sndfile_mutex);
