@@ -204,12 +204,8 @@ ags_volume_channel_set_property(GObject *gobject,
   volume_channel = AGS_VOLUME_CHANNEL(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(volume_channel);
   
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
-
   switch(prop_id){
   case PROP_VOLUME:
     {
@@ -257,11 +253,7 @@ ags_volume_channel_get_property(GObject *gobject,
   volume_channel = AGS_VOLUME_CHANNEL(gobject);
 
   /* get recall mutex */
-  pthread_mutex_lock(ags_recall_get_class_mutex());
-  
-  recall_mutex = AGS_RECALL(gobject)->obj_mutex;
-  
-  pthread_mutex_unlock(ags_recall_get_class_mutex());
+  recall_mutex = AGS_RECALL_GET_OBJ_MUTEX(volume_channel);
 
   switch(prop_id){
   case PROP_VOLUME:
