@@ -55,8 +55,15 @@
 #include <ags/audio/ags_channel.h>
 #include <ags/audio/ags_devout.h>
 #include <ags/audio/ags_devin.h>
+#include <ags/audio/ags_diatonic_scale.h>
 #include <ags/audio/ags_fifoout.h>
+#include <ags/audio/ags_filter_util.h>
+#include <ags/audio/ags_fm_synth_util.h>
+#include <ags/audio/ags_fourier_transform_util.h>
+#include <ags/audio/ags_frequency_map_manager.h>
+#include <ags/audio/ags_frequency_map.h>
 #include <ags/audio/ags_input.h>
+#include <ags/audio/ags_lfo_synth_util.h>
 #include <ags/audio/ags_midi.h>
 #include <ags/audio/ags_midiin.h>
 #include <ags/audio/ags_notation.h>
@@ -91,6 +98,7 @@
 #include <ags/audio/ags_sound_provider.h>
 #include <ags/audio/ags_sequencer_util.h>
 #include <ags/audio/ags_soundcard_util.h>
+#include <ags/audio/ags_synth_enums.h>
 #include <ags/audio/ags_synth_generator.h>
 #include <ags/audio/ags_synth_util.h>
 #include <ags/audio/ags_track.h>
@@ -103,6 +111,7 @@
 #include <ags/audio/thread/ags_sequencer_thread.h>
 #include <ags/audio/thread/ags_soundcard_thread.h>
 #include <ags/audio/thread/ags_export_thread.h>
+#include <ags/audio/thread/ags_sfz_loader.h>
 #include <ags/audio/thread/ags_wave_loader.h>
 
 /* audio file */
@@ -117,6 +126,10 @@
 #include <ags/audio/file/ags_ipatch_sf2_reader.h>
 #include <ags/audio/file/ags_ipatch_sample.h>
 #endif
+#include <ags/audio/file/ags_sfz_file.h>
+#include <ags/audio/file/ags_sfz_group.h>
+#include <ags/audio/file/ags_sfz_region.h>
+#include <ags/audio/file/ags_sfz_sample.h>
 #include <ags/audio/file/ags_sndfile.h>
 #include <ags/audio/file/ags_sound_container.h>
 #include <ags/audio/file/ags_sound_resource.h>
@@ -209,6 +222,10 @@
 #include <ags/audio/recall/ags_feed_channel.h>
 #include <ags/audio/recall/ags_feed_channel_run.h>
 #include <ags/audio/recall/ags_feed_recycling.h>
+#include <ags/audio/recall/ags_lfo_audio_signal.h>
+#include <ags/audio/recall/ags_lfo_channel.h>
+#include <ags/audio/recall/ags_lfo_channel_run.h>
+#include <ags/audio/recall/ags_lfo_recycling.h>
 #include <ags/audio/recall/ags_loop_channel.h>
 #include <ags/audio/recall/ags_loop_channel_run.h>
 #include <ags/audio/recall/ags_mute_audio.h>
