@@ -226,8 +226,12 @@ main(int argc, char **argv)
   CU_pSuite pSuite = NULL;
 
   putenv("LC_ALL=C");
-  putenv("LANG=C");
-  
+  putenv("LANG=C");  
+
+  putenv("LADSPA_PATH=\"\"");
+  putenv("DSSI_PATH=\"\"");
+  putenv("LV2_PATH=\"\"");
+
   /* initialize the CUnit test registry */
   if(CUE_SUCCESS != CU_initialize_registry()){
     return CU_get_error();
